Package: npsp
Type: Package
Title: Nonparametric Spatial Statistics
Version: 0.7-13
Date: 2024-02-17
Authors@R: person("Ruben", "Fernandez-Casal", , "rubenfcasal@gmail.com", role = c("aut", "cre"), 
    comment = c(ORCID = "0000-0002-5785-3739"))
Maintainer: Ruben Fernandez-Casal <rubenfcasal@gmail.com>
Depends: R (>= 2.14.0), graphics
Imports: sp, methods, quadprog, spam
Suggests: gstat, geoR, fields, DEoptim, knitr
Description: Multidimensional nonparametric spatial (spatio-temporal) geostatistics.
    S3 classes and methods for multidimensional: linear binning,
    local polynomial kernel regression (spatial trend estimation), density and variogram estimation.
    Nonparametric methods for simultaneous inference on both spatial trend
    and variogram functions (for spatial processes).
    Nonparametric residual kriging (spatial prediction).
    For details on these methods see, for example, Fernandez-Casal and Francisco-Fernandez (2014) 
    <doi:10.1007/s00477-013-0817-8> or Castillo-Paez et al. (2019) <doi:10.1016/j.csda.2019.01.017>.
License: GPL (>= 2)
URL: https://rubenfcasal.github.io/npsp/,
        https://github.com/rubenfcasal/npsp/
BugReports: https://github.com/rubenfcasal/npsp/issues/
LazyData: yes
Encoding: UTF-8
VignetteBuilder: knitr
RoxygenNote: 7.2.3
NeedsCompilation: yes
Packaged: 2024-02-17 20:30:05 UTC; ruben.fcasal
Author: Ruben Fernandez-Casal [aut, cre]
    (<https://orcid.org/0000-0002-5785-3739>)
Repository: CRAN
Date/Publication: 2024-02-19 17:20:02 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-26 23:14:35 UTC; unix
Archs: npsp.so.dSYM
