# Generated by roxygen2: do not edit by hand

S3method(as.bin.data,SpatialGridDataFrame)
S3method(as.bin.data,bin.data)
S3method(as.bin.data,data.grid)
S3method(as.bin.den,bin.den)
S3method(as.bin.den,data.grid)
S3method(as.data.frame,data.grid)
S3method(as.data.frame,grid.par)
S3method(as.data.grid,SpatialGridDataFrame)
S3method(as.sp,data.grid)
S3method(as.sp,grid.par)
S3method(as.variogram,np.svar)
S3method(as.variogram,svar.bin)
S3method(as.variomodel,svarmod)
S3method(as.vgm,sb.iso)
S3method(as.vgm,svarmod)
S3method(as.vgm,variomodel)
S3method(contour,data.grid)
S3method(coords,data.grid)
S3method(coords,grid.par)
S3method(coordvalues,data.grid)
S3method(coordvalues,grid.par)
S3method(covar,np.svar)
S3method(covar,svarmod)
S3method(dim,data.grid)
S3method(dim,grid.par)
S3method(dimnames,data.grid)
S3method(dimnames,grid.par)
S3method(h.cv,bin.data)
S3method(h.cv,bin.den)
S3method(h.cv,svar.bin)
S3method(image,data.grid)
S3method(interp,data.grid)
S3method(interp,grid.par)
S3method(locpol,bin.data)
S3method(locpol,bin.den)
S3method(locpol,default)
S3method(locpol,svar.bin)
S3method(mask,bin.data)
S3method(mask,bin.den)
S3method(mask,data.grid)
S3method(mask,default)
S3method(mask,locpol.bin)
S3method(np.den,bin.data)
S3method(np.den,bin.den)
S3method(np.den,default)
S3method(np.den,svar.bin)
S3method(np.fitgeo,default)
S3method(np.fitgeo,fitgeo)
S3method(np.fitgeo,locpol.bin)
S3method(np.kriging,default)
S3method(np.kriging,np.geo)
S3method(np.svar,default)
S3method(np.svar,svar.bin)
S3method(persp,data.grid)
S3method(plot,fitgeo)
S3method(plot,fitsvar)
S3method(plot,np.den)
S3method(plot,np.svar)
S3method(plot,svar.bin)
S3method(predict,locpol.bin)
S3method(predict,np.den)
S3method(print,grid.par)
S3method(residuals,locpol.bin)
S3method(residuals,np.geo)
S3method(rule.binning,default)
S3method(rule.svar,bin.den)
S3method(rule.svar,default)
S3method(scattersplot,SpatialPointsDataFrame)
S3method(scattersplot,default)
S3method(simage,data.grid)
S3method(simage,default)
S3method(spersp,data.grid)
S3method(spersp,default)
S3method(spoints,SpatialPointsDataFrame)
S3method(spoints,data.grid)
S3method(spoints,default)
S3method(sv,default)
S3method(sv,sb.iso)
S3method(sv,svar.grid)
S3method(sv,svarmod)
S3method(svar.bin,default)
S3method(svar.grid,svarmod)
S3method(varcov,isotropic)
S3method(varcov,np.svar)
export(.cpu.time.ini)
export(as.bin.data)
export(as.bin.den)
export(as.data.grid)
export(as.sp)
export(as.variogram)
export(as.variomodel)
export(as.vgm)
export(bin.den)
export(binning)
export(coords)
export(coordvalues)
export(covar)
export(cpu.time)
export(data.grid)
export(disc.sb)
export(fitsvar.sb.iso)
export(grid.par)
export(h.cv)
export(hcv.data)
export(hot.colors)
export(interp)
export(is.data.grid)
export(jet.colors)
export(kappasb)
export(kriging.simple)
export(locpol)
export(locpolhcv)
export(mask)
export(np.den)
export(np.fitgeo)
export(np.geo)
export(np.kriging)
export(np.svar)
export(np.svariso)
export(np.svariso.corr)
export(np.svariso.hcv)
export(npsp.tolerance)
export(rule)
export(rule.binning)
export(rule.svar)
export(scattersplot)
export(scolor)
export(simage)
export(spersp)
export(splot)
export(spoints)
export(sv)
export(svar.bin)
export(svar.grid)
export(svariso)
export(svarmod)
export(svarmod.sb.iso)
export(svarmodels)
export(varcov)
export(vgm.tab.svarmod)
import(graphics)
import(sp)
importFrom(grDevices,colorRamp)
importFrom(grDevices,dev.size)
importFrom(grDevices,nclass.FD)
importFrom(grDevices,nclass.Sturges)
importFrom(grDevices,nclass.scott)
importFrom(grDevices,rainbow)
importFrom(grDevices,rgb)
importFrom(methods,as)
importFrom(methods,hasArg)
importFrom(methods,is)
importFrom(quadprog,solve.QP)
importFrom(spam,as.spam)
importFrom(spam,chol.spam)
importFrom(spam,colSums.spam)
importFrom(spam,solve.spam)
importFrom(stats,approx)
importFrom(stats,complete.cases)
importFrom(stats,cov2cor)
importFrom(stats,density)
importFrom(stats,dist)
importFrom(stats,lowess)
importFrom(stats,optim)
importFrom(stats,predict)
importFrom(stats,residuals)
importFrom(utils,flush.console)
importMethodsFrom(spam,"%*%")
importMethodsFrom(spam,"*")
useDynLib(npsp, .registration = TRUE)
